Dictionaries
::::::::::::

.. toctree::
   :caption: Dictionaries
   :maxdepth: 2

   intro-Dictionaries.rst
   Dictionaryoperations.rst
   Dictionarymethods.rst
   Aliasingandcopying.rst
   Sparsematrices.rst
   Glossary.rst
   Exercises.rst
